<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\labeledit.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.labeledit`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\widgets\labeledit.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LabelEdit`




<a href="..\..\qtstrap\widgets\labeledit.py#L7"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.__init__`

```python
__init__(text, *args, changed=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\labeledit.py#L38"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.accept`

```python
accept()
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L42"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.dismiss`

```python
dismiss()
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L45"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.eventFilter`

```python
eventFilter(source, event)
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L34"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.mouseDoubleClickEvent`

```python
mouseDoubleClickEvent(event: PySide6.QtGui.QMouseEvent) → None
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L25"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.setText`

```python
setText(text)
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L29"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.start_editing`

```python
start_editing()
```





---

<a href="..\..\qtstrap\widgets\labeledit.py#L22"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LabelEdit.text`

```python
text()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
